import React, {useState, useRef, ChangeEvent} from 'react'
import {CreateCompletionResponseChoicesInner } from "openai";
import { ApplicationPayloadType } from '../../common/types';
import OpenAPI from '../../common/lib/openApi';


type OwnProps = {
    application: ApplicationPayloadType;
}
 
const Interview = ({application}:OwnProps)=>{
    const [isLoading, setIsLoading] = useState<boolean>(false)
    const [questions, setQuestions] = useState<CreateCompletionResponseChoicesInner[]>([])
    const subject = useRef<string>('')
    const level = useRef<string>('easy')

    const onPressGenerate=()=>{
        if(subject.current.length>0){
            setQuestions([])
            setIsLoading(true)
            OpenAPI.getInterViewQuestions(subject.current, level.current).then(res=>{
                setQuestions(res.data.choices)
                setIsLoading(false)
            })
        }
    }

    const onChange=(e:ChangeEvent<HTMLInputElement>)=>{
        subject.current = e.target.value
    }

    const onSelectLevel = (e: ChangeEvent<HTMLSelectElement>) => {
        level.current = e.target.value
    }

    const renderQuestions=(question:CreateCompletionResponseChoicesInner, index:number)=>{
        return (<p style={{whiteSpace:'pre-line'}}>{question.text}</p>)
    }

    const btnText = isLoading?'Generating..':'Generate'

    return (
    <div>
        <h4>Questions Generator</h4>
        <div className="row g-3" >
            <label className="col-3 col-form-label" >Subject</label> 
            <div className="col-6">
                <div className="row g-3" >
                    <div className="col-8"> <input type="text" className="form-control"  onChange={onChange} /></div>
                    <div className="col-4">
                        <select className="form-select" aria-label="Default select example" onChange={onSelectLevel}>
                            <option value="easy">Easy</option>
                            <option value="intermediate">Medium</option>
                            <option value="hard">Hard</option>
                        </select>     
                    </div>
                </div>
            </div>
            <div className="col-3">
                <button className="btn btn-warning mb-3" onClick={onPressGenerate} disabled={isLoading} >{btnText}</button>
            </div>
        </div>
        <div className='questions-container' >
            {questions.map(renderQuestions)}
        </div>
    </div>)
}

export default Interview;